strategy library
Classes
- StgContext
- Can be provided to strategies, contain payload and the duration of a operation to execute.
- Strategy
- Simple interface to implement a strategy.
Mixins
-
StrategyMixin<
EventType> - Use this to add a strategy invocation functionality to a controller.